# GSDL
Python GUI lib for PyGame
## Links
[Github](https://github.com/Pixelsuft/gsdl) <br />
[PyPi](https://pypi.org/project/gsdl/) <br />
[Example](https://github.com/Pixelsuft/gsdl/blob/main/main.py) <br />
[Issue Tracker](https://github.com/Pixelsuft/gsdl/issues)
## Work In Progress
